// This file is part of Zoph.
//
// Zoph is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// Zoph is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// You should have received a copy of the GNU General Public License
// along with Zoph; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

function branch(obj) {
    obj.nextSibling.nextSibling.style.display="block";
    obj.innerHTML="-&nbsp;";
    obj.onclick=closebranch;
    }

function unbranch(obj) {
    obj.nextSibling.nextSibling.style.display="none";
    obj.innerHTML="+&nbsp;";
    obj.onclick=openbranch;
    }

function openbranch() {
    branch(this);
    }

function closebranch() {
    unbranch(this);
    }

function unbranchall() {
    nodes=getElementsByClass('treenode');
    for(i in nodes) {
        unbranch(nodes[i]);
    }
}

function branchall() {
    nodes=getElementsByClass('treenode');
    for(i in nodes) {
        branch(nodes[i]);
    }
}
